MethodChannelWhatsappDirectSend class
An implementation of WhatsappDirectSendPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- WhatsappDirectSendPlatform
- MethodChannelWhatsappDirectSend
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
{required String phone, required String text, String? filePath}) → Future< void> -
Sends a message via WhatsApp to the given
phonenumber.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited