WhatsappDirectSendPlatform class abstract
The platform interface for the WhatsApp Direct Send plugin.
Platform-specific implementations should extend this class rather than implement it, to ensure they get default method implementations as new methods are added.
- Inheritance
-
- Object
- PlatformInterface
- WhatsappDirectSendPlatform
- Implementers
Constructors
- WhatsappDirectSendPlatform()
- Constructs a WhatsappDirectSendPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
{required String phone, required String text, String? filePath}) → Future< void> -
Sends a message via WhatsApp to the given
phonenumber. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ WhatsappDirectSendPlatform
-
The default instance of WhatsappDirectSendPlatform to use.
getter/setter pair